{% extends 'helpdesk/base.html' %}
{% load bootstrap3 %}

{% block content %}
    <div class="row">
        <div class="col-sm-4 col-sm-push-8">
            <div class="panel panel-primary">
                <div class="panel-heading">
                    <h3 class="panel-title">Filters</h3>
                </div>
                <div class="panel-body">
                    <form method="post">
                        {% csrf_token %}
                        {% bootstrap_form filter_form %}
                        {% bootstrap_button 'Apply' button_type='submit' %}
                    </form>
                </div>
            </div>
        </div>
        <div class="col-sm-8 col-sm-pull-4">
            <div class="row">
                <div class="col-xs-12">
                    <form class="row search-form">
                        <div class="col-lg-8 col-xs-6">
                            {% bootstrap_field search_form.search layout='inline' %}
                        </div>
                        <div class="col-lg-2 col-xs-3">
                            {% bootstrap_button 'Search' button_type='submit' button_class='btn-xs btn-block' %}
                        </div>
                        <div class="col-lg-2 col-xs-3">
                            <a href="?" class="btn btn-xs btn-default">Reset</a>
                        </div>
                    </form>
                </div>
            </div>
            {% include list_template %}
            <div class="text-center">
                {% bootstrap_pagination page_obj extra=extra %}
            </div>
        </div>
    </div>
{% endblock %}
